@@ -13,7 +13,6 @@
 # limitations under the License.
 
 import copy
-from debtcollector import moves
 import logging
 
 import debtcollector
@@ -27,7 +26,6 @@ LOG = logging.getLogger(__name__)
 
 CORS_OPTS = [
     cfg.ListOpt('allowed_origin',
-                default=None,
                 help='Indicate whether this resource may be shared with the '
                      'domain received in the requests "origin" header. '
                      'Format: "<protocol>://<host>[:<port>]", no trailing '
@@ -131,12 +129,6 @@ class CORS(base.ConfigurableMiddleware):
             except Exception:
                 return None
 
-        self.set_latent(
-            allow_headers=sanitize(self.conf.get('latent_allow_headers')),
-            expose_headers=sanitize(self.conf.get('latent_expose_headers')),
-            allow_methods=sanitize(self.conf.get('latent_allow_methods'))
-        )
-
     @classmethod
     def factory(cls, global_conf, **local_conf):
         """factory method for paste.deploy
@@ -148,8 +140,8 @@ class CORS(base.ConfigurableMiddleware):
         allow_methods: List of HTTP methods to permit.
         allow_headers: List of HTTP headers to permit from the client.
         """
-        if ('allowed_origin' not in local_conf
-           and 'oslo_config_project' not in local_conf):
+        if ('allowed_origin' not in local_conf and
+           'oslo_config_project' not in local_conf):
             raise TypeError("allowed_origin or oslo_config_project "
                             "is required")
         return super(CORS, cls).factory(global_conf, **local_conf)
@@ -157,13 +149,6 @@ class CORS(base.ConfigurableMiddleware):
     def _init_conf(self):
         '''Initialize this middleware from an oslo.config instance.'''
 
-        # Set up a location for our latent configuration options
-        self._latent_configuration = {
-            'allow_headers': [],
-            'expose_headers': [],
-            'methods': []
-        }
-
         # First, check the configuration and register global options.
         self.oslo_conf.register_opts(CORS_OPTS, 'cors')
 
@@ -246,42 +231,6 @@ class CORS(base.ConfigurableMiddleware):
                     'allow_headers': allow_headers
                 }
 
-    @moves.moved_method('set_defaults',
-                        message='CORS.set_latent has been deprecated in favor '
-                                'of oslo_middleware.cors.set_defaults')
-    def set_latent(self, allow_headers=None, allow_methods=None,
-                   expose_headers=None):
-        '''Add a new latent property for this middleware.
-
-        Latent properties are those values which a system requires for
-        operation. API-specific headers, for example, may be added by an
-        engineer so that they ship with the codebase, and thus do not require
-        extra documentation or passing of institutional knowledge.
-
-        :param allow_headers: HTTP headers permitted in client requests.
-        :param allow_methods: HTTP methods permitted in client requests.
-        :param expose_headers: HTTP Headers exposed to clients.
-        '''
-
-        if allow_headers:
-            if isinstance(allow_headers, list):
-                self._latent_configuration['allow_headers'] = allow_headers
-            else:
-                raise TypeError("allow_headers must be a list or None.")
-
-        if expose_headers:
-            if isinstance(expose_headers, list):
-                self._latent_configuration['expose_headers'] = expose_headers
-            else:
-                raise TypeError("expose_headers must be a list or None.")
-
-        if allow_methods:
-            if isinstance(allow_methods, list):
-                self._latent_configuration['methods'] = allow_methods
-            else:
-                raise TypeError("allow_methods parameter must be a list or"
-                                " None.")
-
     def process_response(self, response, request=None):
         '''Check for CORS headers, and decorate if necessary.
 
@@ -362,10 +311,7 @@ class CORS(base.ConfigurableMiddleware):
             return response
 
         # Compare request method to permitted methods (Section 6.2.5)
-        permitted_methods = (
-            cors_config['allow_methods'] +
-            self._latent_configuration['methods']
-        )
+        permitted_methods = cors_config['allow_methods']
         if request_method not in permitted_methods:
             LOG.debug('Request method \'%s\' not in permitted list: %s'
                       % (request_method, permitted_methods))
@@ -375,8 +321,7 @@ class CORS(base.ConfigurableMiddleware):
         # (Section 6.2.6)
         permitted_headers = [header.upper() for header in
                              (cors_config['allow_headers'] +
-                              self.simple_headers +
-                              self._latent_configuration['allow_headers'])]
+                              self.simple_headers)]
         for requested_header in request_headers:
             upper_header = requested_header.upper()
             if upper_header not in permitted_headers:
@@ -449,8 +394,7 @@ class CORS(base.ConfigurableMiddleware):
         # Attach the exposed headers and exit. (Section 6.1.4)
         if cors_config['expose_headers']:
             response.headers['Access-Control-Expose-Headers'] = \
-                ','.join(cors_config['expose_headers'] +
-                         self._latent_configuration['expose_headers'])
+                ','.join(cors_config['expose_headers'])
 
 # NOTE(sileht): Shortcut for backwards compatibility
 filter_factory = CORS.factory
